@@ -163,7 +163,6 @@ writelog(FILE *fp)
 
 	git_revwalk_new(&w, repo);
 	git_revwalk_push_head(w);
-	git_revwalk_sorting(w, GIT_SORT_TIME);
 	git_revwalk_simplify_first_parent(w);
 
 	if (git_revwalk_next(&id, w) ||
@@ -210,7 +209,6 @@ usage(const char *argv0)
 int
 main(int argc, char *argv[])
 {
-	const git_error *e = NULL;
 	FILE *fp;
 	char path[PATH_MAX], repodirabs[PATH_MAX + 1];
 	const char *repodir = NULL;
@@ -242,8 +240,7 @@ main(int argc, char *argv[])
 
 		if (git_repository_open_ext(&repo, repodir,
 		    GIT_REPOSITORY_OPEN_NO_SEARCH, NULL)) {
-			e = giterr_last();
-			fprintf(stderr, "%s: %s\n", argv[0], e->message);
+			fprintf(stderr, "%s: cannot open repository\n", argv[0]);
 			ret = 1;
 			continue;
 		}
