@@ -58,7 +58,6 @@ static char *name = "";
 static char *strippedname = "";
 static char description[255];
 static char cloneurl[1024];
-static int hastagsgph;
 static char *submodules;
 static char *licensefiles[] = { "HEAD:LICENSE", "HEAD:LICENSE.md", "HEAD:COPYING" };
 static char *license;
@@ -472,8 +471,6 @@ writeheader(FILE *fp, const char *title)
 	fprintf(fp, "[1|Log|%s/log.gph|server|port]\n", relpath);
 	fprintf(fp, "[1|Files|%s/files.gph|server|port]\n", relpath);
 	fprintf(fp, "[1|Refs|%s/refs.gph|server|port]\n", relpath);
-	if (hastagsgph)
-		fprintf(fp, "[1|Tags|%s/tags.gph|server|port]\n", relpath);
 	if (submodules)
 		fprintf(fp, "[1|Submodules|%s/file/%s.gph|server|port]\n",
 		        relpath, submodules);
@@ -705,7 +702,6 @@ writelog(FILE *fp, const git_oid *oid)
 
 	git_revwalk_new(&w, repo);
 	git_revwalk_push(w, oid);
-	git_revwalk_sorting(w, GIT_SORT_TIME);
 	git_revwalk_simplify_first_parent(w);
 
 	while (!git_revwalk_next(&id, w)) {
@@ -827,7 +823,6 @@ writeatom(FILE *fp)
 
 	git_revwalk_new(&w, repo);
 	git_revwalk_push_head(w);
-	git_revwalk_sorting(w, GIT_SORT_TIME);
 	git_revwalk_simplify_first_parent(w);
 
 	for (i = 0; i < m && !git_revwalk_next(&id, w); i++) {
@@ -1136,7 +1131,6 @@ main(int argc, char *argv[])
 {
 	git_object *obj = NULL;
 	const git_oid *head = NULL;
-	const git_error *e = NULL;
 	mode_t mask;
 	FILE *fp, *fpread;
 	char path[PATH_MAX], repodirabs[PATH_MAX + 1], *p;
@@ -1189,8 +1183,7 @@ main(int argc, char *argv[])
 
 	if (git_repository_open_ext(&repo, repodir,
 		GIT_REPOSITORY_OPEN_NO_SEARCH, NULL) < 0) {
-		e = giterr_last();
-		fprintf(stderr, "%s: %s\n", argv[0], e->message);
+		fprintf(stderr, "%s: cannot open repository\n", argv[0]);
 		return 1;
 	}
 
@@ -1237,9 +1230,6 @@ main(int argc, char *argv[])
 		fclose(fpread);
 	}
 
-	/* check if tags.gph file exists */
-	hastagsgph = (access("tags.gph", F_OK) == 0);
-
 	/* check LICENSE */
 	for (i = 0; i < sizeof(licensefiles) / sizeof(*licensefiles) && !license; i++) {
 		if (!git_revparse_single(&obj, repo, licensefiles[i]) &&
